@@ -36,6 +36,9 @@ INSTALLED_APPS = [
     "django.contrib.messages",
     "rest_framework",
     "drf_yasg",
+    "simple_certmanager",
+    "zgw_consumers",
+    "notifications_api_common",
     "vng_api_common",
     "vng_api_common.authorizations",
     "vng_api_common.notifications",
