@@ -1,7 +1,7 @@
 from django.apps import AppConfig
 from django.db import models
 from django.forms.fields import CharField
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from drf_yasg import openapi
 from drf_yasg.inspectors.field import (
