@@ -2,6 +2,7 @@ from django.conf import settings
 from django.utils.module_loading import import_string
 
 from drf_yasg.utils import swagger_auto_schema
+from notifications_api_common.api.serializers import NotificatieSerializer
 from rest_framework import status
 from rest_framework.response import Response
 from rest_framework.views import APIView
@@ -10,7 +11,6 @@ from ...permissions import AuthScopesRequired
 from ...scopes import Scope
 from ...serializers import FoutSerializer, ValidatieFoutSerializer
 from ..constants import SCOPE_NOTIFICATIES_PUBLICEREN_LABEL
-from .serializers import NotificatieSerializer
 
 
 class NotificationBaseView(APIView):
